require 'httparty'
require 'rails-html-sanitizer'

require "url_2_event/version"
require 'url_2_event/event'
require 'url_2_event/base'
Dir["#{File.dirname(__FILE__)}/url_2_event/adapters/*.rb"].each { |f| require(f) }

module Url2Event
  class InvalidURLError < ArgumentError; end
  class UnsupportedSourceError < StandardError; end
  class UnparsableSourceError < StandardError; end

  class << self
    def parse_event_from_uri(uri)
      url = parse_url(uri)

      klass = get_parser_class(url)
      parser = klass.new(url)
      parser.get_event
    end

    # Returns the appropriate Url2Event subclass for the given url.
    def get_parser_class(uri)
      parser_class = self::Base.implementations.find { |parser|
        parser.is_parser_for?(uri)
      }

      if parser_class
        parser_class
      else
        raise self::UnsupportedSourceError
      end
    end

    private

    def parse_url(uri)
      begin
        url = URI.parse(uri)
      rescue
        raise self::InvalidURLError
      end

      if url.kind_of?(URI::HTTP) || uri.kind_of?(URI::HTTPS)
        url
      else
        raise self::InvalidURLError
      end
    end
  end
end
