module Url2Event
  class Eventbrite < Base
    base_uri 'https://www.eventbriteapi.com'

    class << self
      def is_parser_for?(uri)
        !uri.hostname.match(%r{(?:www\.)?eventbrite\.(com|co\.uk)}).nil?
      end
    end

    def options
      @options = {
        headers: {
          "Authorization" => "Bearer #{ENV['EVENTBRITE_TOKEN']}"
        }
      }
    end

    protected

    def event_endpoint
      "/v3/events/#{get_id}"
    end

    def get_id
      matcher = %r{/e/[^\b]+-(\d+)}
      matches = matcher.match(@uri.path)
      if !matches.nil?
        matches.captures[0]
      else
        raise Url2Event::UnparsableSourceError
      end
    end

    def to_event(response)
      title = response['name']['text'] if response['name']
      link = response['url']

      if desc = response['description']
        description = sanitize(desc['text'])
      end

      if venue = response['venue']
        location = venue['name']
        location += ", " + venue['address_1'] if venue['address_1']
        location += " " + venue['address_2'] if venue['address_2']
        location += ", " + venue['city'] if venue['city']
      end

      if start = response['start']
        begin_at = Time.parse(start['local'] + " +0000")
      end

      if eend = response['end'] # keywords lol
        end_at = Time.parse(eend['local'] + " +0000")
      end

      Event.new(
        title: title,
        description: description,
        location: location,
        begin_at: begin_at,
        end_at: end_at,
        link: link
      )
    end
  end
end
