module Url2Event
  class Base
    attr_accessor :options
    @implementations = []

    class << self
      attr_accessor :implementations

      def inherited(subclass)
        subclass.class_eval do
          include HTTParty
        end
        @implementations << subclass unless @implementations.include?(subclass)
      end

      def is_parser_for?
        raise NotImplementedError, "You should define #{self.class}.#{__method__}."
      end
    end

    def initialize(uri)
      @uri = uri
    end

    def get_event
      response = self.class.get(event_endpoint, options)
      to_event(response)
    end

    def sanitize(raw)
      Rails::Html::FullSanitizer.new().sanitize(raw)
    end

    def to_event
      raise NotImplementedError, "You should define #{self.class}##{__method__}."
    end

    def event_endpoint
      raise NotImplementedError, "You should define #{self.class}##{__method__}."
    end

  end
end
